summaryrefslogtreecommitdiffstats
path: root/kmix/viewswitches.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
commitb1057f437bf65300831a0ccb45b920787c6b318d (patch)
treef8a73db06ca1180d0da0ba6dfbe786197b4f4bc3 /kmix/viewswitches.cpp
parent4ddfca384ced9ad654213aef9dc2c3973720b980 (diff)
downloadtdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.tar.gz
tdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.zip
TQt4 port kdemultimedia
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1236079 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmix/viewswitches.cpp')
-rw-r--r--kmix/viewswitches.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmix/viewswitches.cpp b/kmix/viewswitches.cpp
index 15b555ac..cf5ac958 100644
--- a/kmix/viewswitches.cpp
+++ b/kmix/viewswitches.cpp
@@ -31,8 +31,8 @@
#include "mdwenum.h"
#include "mixer.h"
-ViewSwitches::ViewSwitches(TQWidget* parent, const char* name, const TQString & caption, Mixer* mixer, ViewBase::ViewFlags vflags)
- : ViewBase(parent, name, caption, mixer, 0, vflags)
+ViewSwitches::ViewSwitches(TQWidget* tqparent, const char* name, const TQString & caption, Mixer* mixer, ViewBase::ViewFlags vflags)
+ : ViewBase(tqparent, name, caption, mixer, 0, vflags)
{
// Create switch buttonGroup
if ( _vflags & ViewBase::Vertical ) {
@@ -46,7 +46,7 @@ ViewSwitches::ViewSwitches(TQWidget* parent, const char* name, const TQString &
// Place enums right from the switches: This is done, so that there will be no
// ugly space on the left side, when no Switch is shown.
// Actually it is not really clear yet, why there is empty space at all: There are 0 items in
// the _layoutEnum, so it might be a sizeHint() or some other subtle layout issue.
_layoutEnum = new TQVBoxLayout(_layoutMDW);
}
init();
@@ -92,8 +92,8 @@ TQWidget* ViewSwitches::add(MixDevice *md)
mdw = new MDWEnum(
_mixer, // the mixer for this device
md, // MixDevice (parameter)
- orientation, // Orientation
- this, // parent
+ orientation, // Qt::Orientation
+ this, // tqparent
this, // View widget
md->name().latin1()
);
@@ -107,8 +107,8 @@ TQWidget* ViewSwitches::add(MixDevice *md)
_mixer, // the mixer for this device
md, // MixDevice (parameter)
false, // Small
- orientation, // Orientation
- this, // parent
+ orientation, // Qt::Orientation
+ this, // tqparent
this, // View widget
md->name().latin1()
);
@@ -118,9 +118,9 @@ TQWidget* ViewSwitches::add(MixDevice *md)
return mdw;
}
-TQSize ViewSwitches::sizeHint() const {
- //kdDebug(67100) << "ViewSwitches::sizeHint(): NewSize is " << _layoutMDW->sizeHint() << "\n";
- return( _layoutMDW->sizeHint() );
+TQSize ViewSwitches::tqsizeHint() const {
+ //kdDebug(67100) << "ViewSwitches::tqsizeHint(): NewSize is " << _layoutMDW->tqsizeHint() << "\n";
+ return( _layoutMDW->tqsizeHint() );
}
void ViewSwitches::constructionFinished() {
@@ -46,7 +46,7 @@ ViewSwitches::ViewSwitches(TQWidget* parent, const char* name, const TQString &
// ugly space on the left side, when no Switch is shown.
// Actually it is not really clear yet, why there is empty space at all: There are 0 items in
- // the _layoutEnum, so it might be a sizeHint() or some other subtle layout issue.
+ // the _layoutEnum, so it might be a tqsizeHint() or some other subtle tqlayout issue.
_layoutEnum = new TQVBoxLayout(_layoutMDW);
}